**#Developer : Avik Das, ISB, HYD, Data Scientist**

*##Steps to run the package :*

'''
Note : This function will work for exclusively packages \n
       where you need to shift from one location        \n
       to another location frequently for Logic needs.  \n
       Function is not case-sensistive                  \n
       
sequence_no : Pass the number of steps you want to go back                                           \n
              Start with : 0 which is just the home directory from where you are running the file    \n
source_path : Pass the source path where you want to perform the action                              \n
              Optional : If you have nothing to pass it will get default current working directory ) \n
target_path : Pass the absolute path / list of folders as a sequence you want to traverse as a list  \n 
              Example : For multiple folders --> ['folder1','folder2','folder3',....]                \n
                        For Single absolute path --> folder1/folder2/folder3/.....                   \n
              ( Optional : If you are finding something within just earlier directory )              \n
file_name   : Pass the exact file name or it will return all files as a list                         \n 
              with extensions that you will pass as next parameter                                   \n
              ( Optional : If you need to access exact file only )                                   \n
extension   : Pass the extension of the file you want to use                                         \n
              ( Optional : If you only need to go to path )                                          \n
              Example : txt, py, png etc...
'''

Ex : 
from pathfindwithinspace import pathfinder

If you need to know package working directory and need to do something within it :
print(str(pathfinder.find_file(0,'','','','py')[0]))

If you need to do something within your own designated directory from where the .py file is running :
print(str(pathfinder.find_file(0,os.path.abspath(__file__),'','','py')))
                

*Return the exception details as well *
